==> qtjambi-debuginfo-windows-x64-6.5.4.jar: sources/QtJambiGui/QShowEvent_shell.cpp <==
#include "QShowEvent_shell.h"
#include <QtJambi/Cast>

void deleter_QShowEvent(void *ptr, bool isShell)
{
    QTJAMBI_NATIVE_METHOD_CALL("qtjambi_deleter for QShowEvent")
    QShowEvent *_ptr = reinterpret_cast<QShowEvent *>(ptr);
    if(!isShell){
        QtJambiAPI::registerNonShellDeletion(ptr);
    }
    delete _ptr;
}

QtJambiShell* QShowEvent_shell::__shell() const { return *reinterpret_cast<QtJambiShell**>( quintptr(this) + sizeof(QShowEvent_shell) ); }

jmethodID QShowEvent_shell::__shell_javaMethod(int pos) const { return QShowEvent_shell::__shell()->javaMethod(typeid(QShowEvent), pos); }

// emitting (writeShellConstructor)
QShowEvent_shell::QShowEvent_shell()
    : QShowEvent()
{
    QTJAMBI_IN_CONSTRUCTOR_CALL("QShowEvent::QShowEvent_shell()", QShowEvent_shell::__shell())
    QShowEvent_shell::__shell()->constructed(typeid(QShowEvent));
}

QShowEvent_shell::QShowEvent_shell(const QShowEvent& arg__1)
    : QShowEvent(arg__1)
{
    QTJAMBI_IN_CONSTRUCTOR_CALL("QShowEvent::QShowEvent_shell(const QShowEvent& arg__1)", QShowEvent_shell::__shell())
    QShowEvent_shell::__shell()->constructed(typeid(QShowEvent));
}

// emitting (writeShellDestructor)
QShowEvent_shell::~QShowEvent_shell()
{
    QTJAMBI_IN_DESTRUCTOR_CALL("QShowEvent::~QShowEvent()", QShowEvent_shell::__shell())
    QShowEvent_shell::__shell()->destructed(typeid(QShowEvent));
}

void QShowEvent_shell::operator delete(void * ptr) noexcept {
    reinterpret_cast<QShowEvent_shell*>(ptr)->QShowEvent_shell::__shell()->tryDeleteShell(typeid(QShowEvent));
}

// emitting Virtual overrides (virtualFunctions)
QShowEvent* QShowEvent_shell::clone() const
{
    if(jmethodID method_id = __shell_javaMethod(0)){
        QTJAMBI_JAVA_METHOD_CALL("QShowEvent::clone()const", QShowEvent_shell::__shell())
        if(JniEnvironment __jni_env{200}) {
            QtJambiExceptionHandler __qj_exnhandler;
            QShowEvent*  __qt_return_value = nullptr;
            QTJAMBI_TRY {
                if(jobject __java_this = QShowEvent_shell::__shell()->getJavaObjectLocalRef(__jni_env)){
                    jobject __java_return_value = __jni_env->CallObjectMethod(__java_this, method_id);
                    JavaException::check(__jni_env QTJAMBI_STACKTRACEINFO );
                    __qt_return_value = qtjambi_cast<QShowEvent* >(__jni_env, __java_return_value);
                    QtJambiAPI::setCppOwnership(__jni_env, __java_return_value);
                } else {
                    QShowEvent_shell::__shell()->warnForMethod("QShowEvent::clone()const");
                }
            } QTJAMBI_CATCH(const JavaException& exn){
                __qj_exnhandler.handle(__jni_env, exn, "QShowEvent::clone()const");
            } QTJAMBI_TRY_END
            return __qt_return_value;
        }else{
            return QShowEvent::clone();
        }
    }else{
        return QShowEvent::clone();
    }
}

void QShowEvent_shell::setAccepted(bool accepted0)
{
    if(jmethodID method_id = __shell_javaMethod(1)){
        QTJAMBI_JAVA_METHOD_CALL("QShowEvent::", QShowEvent_shell::__shell())
        if(JniEnvironment __jni_env{300}) {
            QtJambiExceptionHandler __qj_exnhandler;
            QTJAMBI_TRY {
                if(jobject __java_this = QShowEvent_shell::__shell()->getJavaObjectLocalRef(__jni_env)){
                    __jni_env->CallVoidMethod(__java_this, method_id, accepted0);
                    JavaException::check(__jni_env QTJAMBI_STACKTRACEINFO );
                } else {
                    QShowEvent_shell::__shell()->warnForMethod("QShowEvent::");
                }
            } QTJAMBI_CATCH(const JavaException& exn){
                __qj_exnhandler.handle(__jni_env, exn, "QShowEvent::");
            } QTJAMBI_TRY_END
        }else{
            QEvent::setAccepted(static_cast<bool>(accepted0));
        }
    }else{
        QEvent::setAccepted(static_cast<bool>(accepted0));
    }
}

// emitting Functions in shell class (nonVirtualShellFunctions)
// emitting Public Override Functions (publicOverrideFunctions)
void QShowEvent_access::__qt_set_cref_QShowEvent(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID other0)
{
    Q_UNUSED(__jni_env)
    Q_UNUSED(__this_nativeId)
    const QShowEvent& __qt_other0 = QtJambiAPI::objectReferenceFromNativeId<QShowEvent>(__jni_env, other0);
    QShowEvent& __qt_return_value = QShowEvent::operator=(__qt_other0);
    Q_UNUSED(__qt_return_value)
}

// emitting Virtual Override Functions (virtualOverrideFunctions)
jobject QShowEvent_access::__qt_clone(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const
{
    Q_UNUSED(__jni_env)
    Q_ASSERT(!!__this_nativeId);
    if (QtJambiAPI::isShell(__this_nativeId)) {
        QShowEvent* __qt_return_value = QShowEvent::clone();
        jobject __java_return_value = qtjambi_cast<jobject>(__jni_env, __qt_return_value);
        QtJambiAPI::setJavaOwnership(__jni_env, __java_return_value);
        return __java_return_value;
    } else {
        QShowEvent* __qt_return_value = clone();
        jobject __java_return_value = qtjambi_cast<jobject>(__jni_env, __qt_return_value);
        QtJambiAPI::setJavaOwnership(__jni_env, __java_return_value);
        return __java_return_value;
    }
}

// emitting (writeConstructors)
// new QShowEvent()
void __qt_construct_QShowEvent_0(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QShowEvent()")
    Q_UNUSED(__java_arguments)
    QShowEvent *__qt_this = new(__qtjambi_ptr) QShowEvent_shell();
    Q_UNUSED(__jni_object)
    Q_UNUSED(__jni_env)
    Q_UNUSED(__qt_this)
}

// new QShowEvent(QShowEvent)
void __qt_construct_QShowEvent_1(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QShowEvent(QShowEvent)")
    jobject arg__1 = __java_arguments[0].l;
    const QShowEvent& __qt_arg__1 = qtjambi_cast<const QShowEvent& >(__jni_env, arg__1);
    QShowEvent *__qt_this = new(__qtjambi_ptr) QShowEvent_shell(__qt_arg__1);
    Q_UNUSED(__jni_object)
    Q_UNUSED(__qt_this)
}

// destruct QShowEvent_shell
void __qt_destruct_QShowEvent(void* ptr)
{
    QTJAMBI_NATIVE_METHOD_CALL("destruct QShowEvent")
    reinterpret_cast<QShowEvent_shell*>(ptr)->~QShowEvent_shell();
}

// emitting  (functionsInTargetLang writeFinalFunction)
// QShowEvent::QShowEvent()
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_gui_QShowEvent_initialize_1native__Lio_qt_gui_QShowEvent_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object)
{
    QTJAMBI_NATIVE_METHOD_CALL("QShowEvent::QShowEvent()")
    QTJAMBI_TRY {
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QShowEvent_0, sizeof(QShowEvent_shell), typeid(QShowEvent), true, &deleter_QShowEvent, nullptr);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QShowEvent::QShowEvent(QShowEvent)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_gui_QShowEvent_initialize_1native__Lio_qt_gui_QShowEvent_2Lio_qt_gui_QShowEvent_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object,
 jobject arg__1)
{
    QTJAMBI_NATIVE_METHOD_CALL("QShowEvent::QShowEvent(QShowEvent)")
    QTJAMBI_TRY {
        jvalue arguments;
        arguments.l = arg__1;
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QShowEvent_1, sizeof(QShowEvent_shell), typeid(QShowEvent), true, &deleter_QShowEvent, &arguments);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QShowEvent::operator=(QShowEvent)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_gui_QShowEvent_set_1native_1cref_1QShowEvent__JJ)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 QtJambiNativeID other0)
{
    Q_UNUSED(__this)
    QTJAMBI_TRY {
        QShowEvent *__qt_this = QtJambiAPI::objectFromNativeId<QShowEvent>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QShowEvent::operator=(QShowEvent)", __qt_this)
        static_cast<QShowEvent_access*>(__qt_this)->__qt_set_cref_QShowEvent(__jni_env, __this_nativeId, other0);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QShowEvent::clone()const
extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_gui_QShowEvent_clone_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jobject __java_return_value{0};
    QTJAMBI_TRY {
        const QShowEvent *__qt_this = QtJambiAPI::objectFromNativeId<QShowEvent>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QShowEvent::clone()const", __qt_this)
        __java_return_value = static_cast<const QShowEvent_access*>(__qt_this)->__qt_clone(__jni_env, __this_nativeId);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// emitting (writeJavaLangObjectOverrideFunctions)

void initialize_meta_info_QShowEvent(){
    using namespace RegistryAPI;
    const std::type_info& typeId = registerObjectTypeInfo<QShowEvent>("QShowEvent", "io/qt/gui/QShowEvent");
// BEGIN: function table
    registerFunctionInfos(typeId, {
        FunctionInfo(/* 0 */ "clone", "()Lio/qt/gui/QShowEvent;"),
        FunctionInfo(/* 1 */ "setAccepted", "(Z)V")});
    registerConstructorInfos(typeId, &__qt_destruct_QShowEvent, {
        ConstructorInfo(&__qt_construct_QShowEvent_0, nullptr)
       ,ConstructorInfo(&__qt_construct_QShowEvent_1, "Lio/qt/gui/QShowEvent;")
    });
// END: function table

// BEGIN: type registration
    registerDeleter(typeId, &deleter_QShowEvent);
    registerSizeOfShell(typeId, sizeof(QShowEvent_shell));
// END: type registration

// BEGIN: polymorphic ids
    registerDefaultPolymorphyHandler<QEvent, QShowEvent>();
// END: polymorphic ids


// BEGIN: enums and flags
// END: enums and flags
}

==> qtjambi-debuginfo-windows-x64-6.6.3.jar: sources/QtJambiGui/QShowEvent_shell.cpp <==
#include "QShowEvent_shell.h"
#include <QtJambi/Cast>

void deleter_QShowEvent(void *ptr, bool isShell)
{
    QTJAMBI_NATIVE_METHOD_CALL("qtjambi_deleter for QShowEvent")
    QShowEvent *_ptr = reinterpret_cast<QShowEvent *>(ptr);
    if(!isShell){
        QtJambiAPI::registerNonShellDeletion(ptr);
    }
    delete _ptr;
}

QtJambiShell* QShowEvent_shell::__shell() const { return *reinterpret_cast<QtJambiShell**>( quintptr(this) + sizeof(QShowEvent_shell) ); }

jmethodID QShowEvent_shell::__shell_javaMethod(int pos) const { return QShowEvent_shell::__shell()->javaMethod(typeid(QShowEvent), pos); }

// emitting (writeShellConstructor)
QShowEvent_shell::QShowEvent_shell()
    : QShowEvent()
{
    QTJAMBI_IN_CONSTRUCTOR_CALL("QShowEvent::QShowEvent_shell()", QShowEvent_shell::__shell())
    QShowEvent_shell::__shell()->constructed(typeid(QShowEvent));
}

QShowEvent_shell::QShowEvent_shell(const QShowEvent& arg__1)
    : QShowEvent(arg__1)
{
    QTJAMBI_IN_CONSTRUCTOR_CALL("QShowEvent::QShowEvent_shell(const QShowEvent& arg__1)", QShowEvent_shell::__shell())
    QShowEvent_shell::__shell()->constructed(typeid(QShowEvent));
}

// emitting (writeShellDestructor)
QShowEvent_shell::~QShowEvent_shell()
{
    QTJAMBI_IN_DESTRUCTOR_CALL("QShowEvent::~QShowEvent()", QShowEvent_shell::__shell())
    QShowEvent_shell::__shell()->destructed(typeid(QShowEvent));
}

void QShowEvent_shell::operator delete(void * ptr) noexcept {
    reinterpret_cast<QShowEvent_shell*>(ptr)->QShowEvent_shell::__shell()->tryDeleteShell(typeid(QShowEvent));
}

// emitting Virtual overrides (virtualFunctions)
QShowEvent* QShowEvent_shell::clone() const
{
    if(jmethodID method_id = __shell_javaMethod(0)){
        QTJAMBI_JAVA_METHOD_CALL("QShowEvent::clone()const", QShowEvent_shell::__shell())
        if(JniEnvironment __jni_env{200}) {
            QtJambiExceptionHandler __qj_exnhandler;
            QShowEvent*  __qt_return_value = nullptr;
            QTJAMBI_TRY {
                if(jobject __java_this = QShowEvent_shell::__shell()->getJavaObjectLocalRef(__jni_env)){
                    jobject __java_return_value = __jni_env->CallObjectMethod(__java_this, method_id);
                    JavaException::check(__jni_env QTJAMBI_STACKTRACEINFO );
                    __qt_return_value = qtjambi_cast<QShowEvent* >(__jni_env, __java_return_value);
                    QtJambiAPI::setCppOwnership(__jni_env, __java_return_value);
                } else {
                    QShowEvent_shell::__shell()->warnForMethod("QShowEvent::clone()const");
                }
            } QTJAMBI_CATCH(const JavaException& exn){
                __qj_exnhandler.handle(__jni_env, exn, "QShowEvent::clone()const");
            } QTJAMBI_TRY_END
            return __qt_return_value;
        }else{
            return QShowEvent::clone();
        }
    }else{
        return QShowEvent::clone();
    }
}

void QShowEvent_shell::setAccepted(bool accepted0)
{
    if(jmethodID method_id = __shell_javaMethod(1)){
        QTJAMBI_JAVA_METHOD_CALL("QShowEvent::", QShowEvent_shell::__shell())
        if(JniEnvironment __jni_env{300}) {
            QtJambiExceptionHandler __qj_exnhandler;
            QTJAMBI_TRY {
                if(jobject __java_this = QShowEvent_shell::__shell()->getJavaObjectLocalRef(__jni_env)){
                    __jni_env->CallVoidMethod(__java_this, method_id, accepted0);
                    JavaException::check(__jni_env QTJAMBI_STACKTRACEINFO );
                } else {
                    QShowEvent_shell::__shell()->warnForMethod("QShowEvent::");
                }
            } QTJAMBI_CATCH(const JavaException& exn){
                __qj_exnhandler.handle(__jni_env, exn, "QShowEvent::");
            } QTJAMBI_TRY_END
        }else{
            QEvent::setAccepted(static_cast<bool>(accepted0));
        }
    }else{
        QEvent::setAccepted(static_cast<bool>(accepted0));
    }
}

// emitting Functions in shell class (nonVirtualShellFunctions)
// emitting Public Override Functions (publicOverrideFunctions)
void QShowEvent_access::__qt_set_cref_QShowEvent(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID other0)
{
    Q_UNUSED(__jni_env)
    Q_UNUSED(__this_nativeId)
    const QShowEvent& __qt_other0 = QtJambiAPI::objectReferenceFromNativeId<QShowEvent>(__jni_env, other0);
    QShowEvent& __qt_return_value = QShowEvent::operator=(__qt_other0);
    Q_UNUSED(__qt_return_value)
}

// emitting Virtual Override Functions (virtualOverrideFunctions)
jobject QShowEvent_access::__qt_clone_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const
{
    Q_UNUSED(__jni_env)
    Q_ASSERT(!!__this_nativeId);
    if (QtJambiAPI::isShell(__this_nativeId)) {
        QShowEvent* __qt_return_value = QShowEvent::clone();
        jobject __java_return_value = qtjambi_cast<jobject>(__jni_env, __qt_return_value);
        QtJambiAPI::setJavaOwnership(__jni_env, __java_return_value);
        return __java_return_value;
    } else {
        QShowEvent* __qt_return_value = clone();
        jobject __java_return_value = qtjambi_cast<jobject>(__jni_env, __qt_return_value);
        QtJambiAPI::setJavaOwnership(__jni_env, __java_return_value);
        return __java_return_value;
    }
}

// emitting (writeConstructors)
// new QShowEvent()
void __qt_construct_QShowEvent(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments, bool __qtjambi_is_generic)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QShowEvent()")
    Q_UNUSED(__java_arguments)
    QShowEvent *__qt_this = new(__qtjambi_ptr) QShowEvent_shell();
    Q_UNUSED(__qtjambi_is_generic)
    Q_UNUSED(__jni_object)
    Q_UNUSED(__jni_env)
    Q_UNUSED(__qt_this)
}

// QShowEvent::QShowEvent()
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_gui_QShowEvent_initialize_1native__Lio_qt_gui_QShowEvent_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object)
{
    QTJAMBI_NATIVE_METHOD_CALL("QShowEvent::QShowEvent()")
    QTJAMBI_TRY {
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QShowEvent, sizeof(QShowEvent_shell), typeid(QShowEvent), true, &deleter_QShowEvent, nullptr);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// new QShowEvent(QShowEvent)
void __qt_construct_QShowEvent_cref_QShowEvent(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments, bool __qtjambi_is_generic)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QShowEvent(QShowEvent)")
    jobject arg__1 = __java_arguments[0].l;
    const QShowEvent& __qt_arg__1 = qtjambi_cast<const QShowEvent& >(__jni_env, arg__1);
    QShowEvent *__qt_this = new(__qtjambi_ptr) QShowEvent_shell(__qt_arg__1);
    Q_UNUSED(__qtjambi_is_generic)
    Q_UNUSED(__jni_object)
    Q_UNUSED(__qt_this)
}

// QShowEvent::QShowEvent(QShowEvent)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_gui_QShowEvent_initialize_1native__Lio_qt_gui_QShowEvent_2Lio_qt_gui_QShowEvent_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object,
 jobject arg__1)
{
    QTJAMBI_NATIVE_METHOD_CALL("QShowEvent::QShowEvent(QShowEvent)")
    QTJAMBI_TRY {
        jvalue arguments;
        arguments.l = arg__1;
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QShowEvent_cref_QShowEvent, sizeof(QShowEvent_shell), typeid(QShowEvent), true, &deleter_QShowEvent, &arguments);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// destruct QShowEvent_shell
void __qt_destruct_QShowEvent(void* ptr)
{
    QTJAMBI_NATIVE_METHOD_CALL("destruct QShowEvent")
    reinterpret_cast<QShowEvent_shell*>(ptr)->~QShowEvent_shell();
}

// emitting  (functionsInTargetLang writeFinalFunction)
// QShowEvent::operator=(QShowEvent)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_gui_QShowEvent_set_1native_1cref_1QShowEvent__JJ)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 QtJambiNativeID other0)
{
    Q_UNUSED(__this)
    QTJAMBI_TRY {
        QShowEvent *__qt_this = QtJambiAPI::objectFromNativeId<QShowEvent>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QShowEvent::operator=(QShowEvent)", __qt_this)
        static_cast<QShowEvent_access*>(__qt_this)->__qt_set_cref_QShowEvent(__jni_env, __this_nativeId, other0);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QShowEvent::clone()const
extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_gui_QShowEvent_clone_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jobject __java_return_value{0};
    QTJAMBI_TRY {
        const QShowEvent *__qt_this = QtJambiAPI::objectFromNativeId<QShowEvent>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QShowEvent::clone()const", __qt_this)
        __java_return_value = static_cast<const QShowEvent_access*>(__qt_this)->__qt_clone_constfct(__jni_env, __this_nativeId);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// emitting (writeJavaLangObjectOverrideFunctions)

void initialize_meta_info_QShowEvent(){
    using namespace RegistryAPI;
    const std::type_info& typeId = registerObjectTypeInfo<QShowEvent>("QShowEvent", "io/qt/gui/QShowEvent");
// BEGIN: function table
    registerFunctionInfos(typeId, {
        FunctionInfo(/* 0 */ "clone", "()Lio/qt/gui/QShowEvent;"),
        FunctionInfo(/* 1 */ "setAccepted", "(Z)V")});
    registerConstructorInfos(typeId, &__qt_destruct_QShowEvent, {
        ConstructorInfo(&__qt_construct_QShowEvent, nullptr)
       ,ConstructorInfo(&__qt_construct_QShowEvent_cref_QShowEvent, "Lio/qt/gui/QShowEvent;")
    });
// END: function table

// BEGIN: type registration
    registerDeleter(typeId, &deleter_QShowEvent);
    registerSizeOfShell(typeId, sizeof(QShowEvent_shell));
// END: type registration

// BEGIN: polymorphic ids
    registerDefaultPolymorphyHandler<QEvent, QShowEvent>();
// END: polymorphic ids


// BEGIN: enums and flags
// END: enums and flags
}
